InferCtxtUndoLogs

Struct InferCtxtUndoLogs 

pub(crate) struct InferCtxtUndoLogs<'db> {
    logs: Vec<UndoLog<'db>>,
    num_open_snapshots: usize,
}
The combined undo log for all the various unification tables. For each change to the storage for any kind of inference variable, we record an UndoLog entry in the vector here.

Fields

logs: Vec<UndoLog<'db>>num_open_snapshots: usize

Implementations

Source

impl<'db> InferCtxtUndoLogs<'db>

pub(crate) fn start_snapshot(&mut self) -> Snapshot

pub(crate) fn region_constraints_in_snapshot( &self, s: &Snapshot, ) -> impl Iterator<Item = &UndoLog<'db>> + Clone

pub(crate) fn opaque_types_in_snapshot(&self, s: &Snapshot) -> bool

fn assert_open_snapshot(&self, snapshot: &Snapshot)